BarcodeCapture class

This class represents a scanned barcode.

Constructors

BarcodeCapture({List<Barcode> barcodes = const <Barcode>[], double? height, Uint8List? image, dynamic raw, double? width})
Create a new BarcodeCapture instance.

Properties

barcodes → List<Barcode>
The list of scanned barcodes.
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
The height of the scanned barcode.
no setter
image → Uint8List?
The bytes of the image that is embedded in the barcode.
final
raw → dynamic
The raw data of the scanned barcode.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → Size
The size of the scanned barcode.
final
width → double
The width of the scanned barcode.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited