MobileScannerArguments class

The start arguments of the scanner.

Constructors

MobileScannerArguments({required Size size, required bool hasTorch, int? textureId, String? webId, int? numberOfCameras})

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasTorch → bool
A bool which is true if the device has a torch.
final
numberOfCameras → int?
Indicates how many cameras are available.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → Size
The output size of the camera. This value can be used to draw a box in the image.
final
textureId → int?
The texture id of the capture used internally.
final
webId → String?
The texture id of the capture used internally if device is web.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited